import React from "react";
import PropTypes from "prop-types";
import { Grid, Link } from "@material-ui/core";
import { makeStyles } from "@material-ui/core/styles";
import { useTranslation } from "react-i18next";
import SlimChips from "../../../../components/common/chips/SlimChips";
import styles from "../../../../components/common/styles/gridStyles";

const useStyles = makeStyles(styles);

const ForwardSummary = ({ forward, handleForwardClick }) => {
  const classes = useStyles();
  const { t } = useTranslation();

  return (
    <Grid container>
      <Grid item xs={12} sm={6} md={3}>
        {`${t("Forward.From")}: `}
        <span className={classes.value}>
          <Link href="#" onClick={handleForwardClick(forward)}>
            {forward.from}
          </Link>
        </span>
      </Grid>

      <Grid item xs={12} sm={6} md={3}>
        {`${t("Forward.To")}: `}
        <span className={classes.value}>{forward.to}</span>
      </Grid>
      {forward.protocols && (
        <Grid item xs={12} sm={6} md={3}>
          {`${t("Forward.Protocols")}: `}
          <SlimChips elements={forward.protocols} />
        </Grid>
      )}
    </Grid>
  );
};

ForwardSummary.propTypes = {
  forward: PropTypes.object.isRequired,
  handleForwardClick: PropTypes.func.isRequired
};

export default ForwardSummary;
