import React from "react";
import PropTypes from "prop-types";
import ExpandableCard from "../../../../../../components/common/ExpandableCard";
import { useTranslation } from "react-i18next";
import { List } from "@material-ui/icons";
import { makeStyles } from "@material-ui/core/styles";
import {
  Table,
  TableBody,
  TableContainer,
  TableHead,
  TableRow,
  Paper
} from "@material-ui/core";
import styles from "../../../../../../components/common/styles/tableStyles";
import {
  StyledTableCell,
  StyledTableRow
} from "../../../../../../components/common/MaterialTable";

const useStyles = makeStyles(styles);

const SpecificHeaderRules = ({ rules }) => {
  const classes = useStyles();
  const { t } = useTranslation();
  return (
    <ExpandableCard
      Icon={<List />}
      iconVariant="rounded"
      title={t("Forward.Options.SpecificHeaders.Rules")}
      smallHeader
      Content={
        <TableContainer component={Paper}>
          <Table
            className={classes.narrowTable}
            size="small"
            aria-label="customized table"
          >
            <TableHead>
              <TableRow>
                <StyledTableCell>
                  {t("Forward.Options.SpecificHeaders.Header")}
                </StyledTableCell>
                <StyledTableCell>
                  {t("Forward.Options.SpecificHeaders.Value")}
                </StyledTableCell>
                <StyledTableCell>
                  {t("Forward.Options.SpecificHeaders.Direction")}
                </StyledTableCell>
                <StyledTableCell>
                  {t("Forward.Options.SpecificHeaders.Action")}
                </StyledTableCell>
              </TableRow>
            </TableHead>
            <TableBody>
              <>
                {rules.map(rule => {
                  return (
                    <StyledTableRow key={rules.indexOf(rule)}>
                      <StyledTableCell>{rule.header}</StyledTableCell>
                      <StyledTableCell>{rule.value}</StyledTableCell>
                      <StyledTableCell>{rule.direction}</StyledTableCell>
                      <StyledTableCell>{rule.action}</StyledTableCell>
                    </StyledTableRow>
                  );
                })}
              </>
            </TableBody>
          </Table>
        </TableContainer>
      }
    />
  );
};

SpecificHeaderRules.propTypes = {
  rules: PropTypes.array.isRequired
};

export default SpecificHeaderRules;
