import React, { useEffect } from "react";
import { connect } from "react-redux";
import { bindActionCreators } from "redux";
import PropTypes from "prop-types";
import { loadServerData } from "../actionCreators";
import ServerComponent from "./ServerComponent";
import { withRouter } from "react-router-dom";
import { summonWizard } from "../../chatbot/actionCreators";

const ServerContainer = ({ actions, data, serverHost, history }) => {
  useEffect(() => {
    actions.loadServerData();
  }, []);

  const openAbout = event => {
    history.push("/about");
    event.preventDefault();
  };

  const handleOpenInNewTab = url => event => {
    window.open(url, "_blank");
    event.preventDefault();
  };

  return (
    <ServerComponent
      data={data}
      serverHost={serverHost}
      openAbout={openAbout}
      handleOpenInNewTab={handleOpenInNewTab}
      summonWizard={actions.summonWizard}
    />
  );
};

ServerContainer.propTypes = {
  actions: PropTypes.object.isRequired,
  data: PropTypes.object.isRequired,
  history: PropTypes.object.isRequired,
  serverHost: PropTypes.string
};

function mapStateToProps(state) {
  return {
    data: state.server.data,
    serverHost: state.server.activeSession.hostName
  };
}

function mapDispatchToProps(dispatch) {
  return {
    actions: bindActionCreators({ loadServerData, summonWizard }, dispatch)
  };
}

export default connect(
  mapStateToProps,
  mapDispatchToProps
)(withRouter(ServerContainer));
