import React from "react";
import PropTypes from "prop-types";
import { makeStyles } from "@material-ui/core/styles";
import clsx from "clsx";
import {
  Card,
  CardHeader,
  CardContent,
  CardActions,
  Collapse,
  Avatar,
  IconButton,
  Tooltip,
  Menu,
  MenuItem
} from "@material-ui/core";
import ExpandMoreIcon from "@material-ui/icons/ExpandMore";
import MoreVertIcon from "@material-ui/icons/MoreVert";
import BubbleChartIcon from "@material-ui/icons/BubbleChart";
import styles from "../../../components/common/styles/expandableCardStyles";
import SystemSummary from "./SystemSummary";
import { useTranslation } from "react-i18next";
import SystemExtensionArea from "./SystemExtensionArea";
import LibraryBooksIcon from "@material-ui/icons/LibraryBooks";
import { useDocumentation } from "../../../hooks";

const useStyles = makeStyles(styles);

const SystemComponent = ({ data, onRedirect }) => {
  const classes = useStyles();
  const { t } = useTranslation();
  const { openDocumentation } = useDocumentation();

  const [expanded, setExpanded] = React.useState(false);
  const [anchorEl, setAnchorEl] = React.useState(null);

  const handleExpandClick = () => {
    setExpanded(!expanded);
  };

  const handleMoreClick = event => {
    setAnchorEl(event.currentTarget);
  };

  const handleClose = () => {
    setAnchorEl(null);
  };

  return (
    <>
      <Menu
        id="system-actions-menu"
        anchorEl={anchorEl}
        keepMounted
        open={Boolean(anchorEl)}
        onClose={handleClose}
      >
        <MenuItem onClick={onRedirect("/about", handleClose)}>
          {t("Menu.About")}
        </MenuItem>
        <MenuItem onClick={onRedirect("/sessions", handleClose)}>
          {t("Menu.Sessions")}
        </MenuItem>
        <MenuItem onClick={onRedirect("/release-notes", handleClose)}>
          {t("Menu.ReleaseNotes")}
        </MenuItem>
      </Menu>
      <Card>
        <CardHeader
          avatar={
            <Avatar aria-label="recipe" className={classes.avatar}>
              <BubbleChartIcon />
            </Avatar>
          }
          action={
            <IconButton
              aria-label="more"
              onClick={handleMoreClick}
              color="primary"
            >
              <MoreVertIcon />
            </IconButton>
          }
          title={<strong>{t("System.Title")}</strong>}
          subheader={t("System.Subtitle")}
        />
        <CardContent>
          {data.loaded && <SystemSummary data={data} />}
        </CardContent>
        <CardActions disableSpacing>
          <Tooltip title={t("About.Actions.Documentation")}>
            <IconButton aria-label="documentation" onClick={openDocumentation}>
              <LibraryBooksIcon />
            </IconButton>
          </Tooltip>
          <IconButton
            className={clsx(classes.expand, {
              [classes.expandOpen]: expanded
            })}
            onClick={handleExpandClick}
            aria-expanded={expanded}
            aria-label="show more"
          >
            <ExpandMoreIcon />
          </IconButton>
        </CardActions>
        <Collapse in={expanded} timeout="auto" unmountOnExit>
          <CardContent>
            <SystemExtensionArea />
          </CardContent>
        </Collapse>
      </Card>
    </>
  );
};

SystemComponent.propTypes = {
  data: PropTypes.object.isRequired,
  onRedirect: PropTypes.func.isRequired
};

export default SystemComponent;
